guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

01/01: gnu: wicd: Allow wicd-gtk to find its icons.


From: Mark H. Weaver
Subject: 01/01: gnu: wicd: Allow wicd-gtk to find its icons.
Date: Thu, 05 Feb 2015 06:31:19 +0000

mhw pushed a commit to branch master
in repository guix.

commit 800d8d406186b22ea503896c2d522ff184620a7a
Author: Mark H Weaver <address@hidden>
Date:   Thu Feb 5 01:25:12 2015 -0500

    gnu: wicd: Allow wicd-gtk to find its icons.
    
    * gnu/packages/wicd.scm (wicd)[inputs]: Add hicolor-icon-theme.
      [arguments]: Install icons in $out/share/icons.  Install a copy of
      'index.theme' from 'hicolor-icon-theme' into $out/share/icons/hicolor.
---
 gnu/packages/wicd.scm |   37 +++++++++++++++++++++++--------------
 1 files changed, 23 insertions(+), 14 deletions(-)

diff --git a/gnu/packages/wicd.scm b/gnu/packages/wicd.scm
index c66e4b0..9f56d58 100644
--- a/gnu/packages/wicd.scm
+++ b/gnu/packages/wicd.scm
@@ -25,6 +25,7 @@
   #:use-module (guix utils)
   #:use-module (gnu packages glib)
   #:use-module (gnu packages gtk)
+  #:use-module (gnu packages gnome)
   #:use-module (gnu packages gettext)
   #:use-module (gnu packages linux)
   #:use-module (gnu packages admin)
@@ -54,7 +55,8 @@
               ("wpa-supplicant" ,wpa-supplicant)
               ("net-tools" ,net-tools)
               ("isc-dhcp" ,isc-dhcp)
-              ("iproute" ,iproute)))
+              ("iproute" ,iproute)
+              ("hicolor-icon-theme" ,hicolor-icon-theme)))
     (arguments
      `(#:python ,python-2
        #:tests? #f                      ; test suite requires networking
@@ -140,7 +142,7 @@
                                    out "/share/gnome-shell-extensions")
                     (string-append "--icons=" out "/share/icons/hicolor")
                     (string-append "--pixmaps=" out "/share/pixmaps")
-                    (string-append "--images=" out "/share/wicd/icons")
+                    (string-append "--images=" out "/share/icons")
                     (string-append "--dbus=" out "/etc/dbus-1/system.d")
                     (string-append "--dbus-service="
                                    out "/share/dbus-1/system-services")
@@ -157,18 +159,25 @@
                       "python setup.py" "configure" params)
               (zero? (apply system* "python" "setup.py" "configure" params)))))
         (alist-cons-after
-         'install 'install-dhclient.conf.template.default
-         (lambda* (#:key outputs #:allow-other-keys)
-           ;; wicd's installer tries to put dhclient.conf.template.default
-           ;; in /etc/wicd/other, which is not available in the build
-           ;; environment, so here we install it manually in the output
-           ;; directory.
-           (let* ((out (assoc-ref outputs "out"))
-                  (dest-dir (string-append out "/etc/wicd"))
-                  (name "dhclient.conf.template.default"))
-             (mkdir-p dest-dir)
-             (copy-file (string-append "other/" name)
-                        (string-append dest-dir "/" name))
+         'install 'post-install
+         (lambda* (#:key inputs outputs #:allow-other-keys)
+           (let ((out (assoc-ref outputs "out")))
+             ;; wicd's installer tries to put dhclient.conf.template.default
+             ;; in /etc/wicd/other, which is not available in the build
+             ;; environment, so here we install it manually in the output
+             ;; directory.
+             (let ((dest-dir (string-append out "/etc/wicd"))
+                   (name "dhclient.conf.template.default"))
+               (mkdir-p dest-dir)
+               (copy-file (string-append "other/" name)
+                          (string-append dest-dir "/" name)))
+
+             ;; Copy index.theme from hicolor-icon-theme.  This is needed to
+             ;; allow wicd-gtk to find its icons.
+             (let ((hicolor (assoc-ref inputs "hicolor-icon-theme"))
+                   (name "/share/icons/hicolor/index.theme"))
+               (copy-file (string-append hicolor name)
+                          (string-append out name)))
              #t))
          %standard-phases))))
     (synopsis "Network connection manager")



reply via email to

[Prev in Thread] Current Thread [Next in Thread]